@@ -13,12 +13,12 @@ if (getRversion() >= "3.1.0") {
 #'     See \code{googledrive::drive_mkdir}. Default \code{FALSE}.
 #' @param overwrite Logical. Passed to \code{googledrive::drive_mkdir}.
 #' @export
-#' @importFrom googledrive drive_mkdir
 #' @inheritParams Cache
 checkAndMakeCloudFolderID <- function(cloudFolderID = getOption('reproducible.cloudFolderID', NULL),
                                       cacheRepo = NULL,
                                       create = FALSE,
                                       overwrite = FALSE) {
+  if (!requireNamespace("googledrive")) stop(requireNamespaceMsg("googledrive", "to use google drive files"))
   browser(expr = exists("._checkAndMakeCloudFolderID_1"))
   if (!is(cloudFolderID, "dribble")) {
     isNullCFI <- is.null(cloudFolderID)
@@ -30,9 +30,9 @@ checkAndMakeCloudFolderID <- function(cloudFolderID = getOption('reproducible.cl
     }
     isID <- isTRUE(32 <= nchar(cloudFolderID) && nchar(cloudFolderID) <= 33)
     driveLs <- if (isID) {
-      tryCatch(drive_get(as_id(cloudFolderID)), error = function(x) {character()})
+      tryCatch(googledrive::drive_get(googledrive::as_id(cloudFolderID)), error = function(x) {character()})
     } else {
-      tryCatch(drive_get(cloudFolderID), error = function(x) { character() })
+      tryCatch(googledrive::drive_get(cloudFolderID), error = function(x) { character() })
     }
 
     if (NROW(driveLs) == 0) {
@@ -43,7 +43,7 @@ checkAndMakeCloudFolderID <- function(cloudFolderID = getOption('reproducible.cl
           }
           cloudFolderID <- cloudFolderFromCacheRepo(cacheRepo)
         }
-        newDir <- drive_mkdir(cloudFolderID, path = "~/", overwrite = overwrite)
+        newDir <- googledrive::drive_mkdir(cloudFolderID, path = "~/", overwrite = overwrite)
         cloudFolderID <- newDir
       }
     } else {
@@ -59,24 +59,26 @@ checkAndMakeCloudFolderID <- function(cloudFolderID = getOption('reproducible.cl
 }
 
 driveLs <- function(cloudFolderID = NULL, pattern = NULL) {
+  if (!requireNamespace("googledrive")) stop(requireNamespaceMsg("googledrive", "to use google drive files"))
   browser(expr = exists("kkkk"))
   if (!is(cloudFolderID, "tbl"))
     cloudFolderID <- checkAndMakeCloudFolderID(cloudFolderID = cloudFolderID, create = FALSE) # only deals with NULL case
   message("Retrieving file list in cloud folder")
-  gdriveLs <- retry(quote(drive_ls(path = cloudFolderID,
-                           pattern = paste0(collapse = "|", c(cloudFolderID$id ,pattern)))))
+  gdriveLs <- retry(quote(googledrive::drive_ls(path = cloudFolderID,
+                                   pattern = paste0(collapse = "|", c(cloudFolderID$id ,pattern)))))
   if (is(gdriveLs, "try-error")) {
     fnf <- grepl("File not found", gdriveLs)
     if (!fnf) {
-      gdriveLs <- retry(quote(drive_ls(path = as_id(cloudFolderID),
+      gdriveLs <- retry(quote(googledrive::drive_ls(path = googledrive::as_id(cloudFolderID),
                                        pattern = paste0(cloudFolderID, "|",pattern))))
       #cloudFolderID <- checkAndMakeCloudFolderID(cloudFolderID, create = TRUE)
-      #gdriveLs <- try(drive_ls(path = as_id(cloudFolderID), pattern = paste0(cloudFolderID, "|",pattern)))
+      #gdriveLs <- try(googledrive::drive_ls(path = googledrive::as_id(cloudFolderID), pattern = paste0(cloudFolderID, "|",pattern)))
     } else {
       stop("cloudFolderID not found on Gdrive\n", gdriveLs)
     }
   }
   gdriveLs
+
 }
 #' Upload to cloud, if necessary
 #'
@@ -84,12 +86,11 @@ driveLs <- function(cloudFolderID = NULL, pattern = NULL) {
 #'
 #' @param isInRepo A data.table with the information about an object that is in the local cacheRepo
 #' @param outputHash The \code{cacheId} of the object to upload
-#' @param gdriveLs The result of \code{googledrive::drive_ls(as_id(cloudFolderID), pattern = "outputHash")}
+#' @param gdriveLs The result of \code{googledrive::drive_ls(googledrive::as_id(cloudFolderID), pattern = "outputHash")}
 #' @param output The output object of FUN that was run in \code{Cache}
-#' @importFrom googledrive drive_upload
-#' @importFrom tools file_ext
 #' @inheritParams Cache
 cloudUpload <- function(isInRepo, outputHash, gdriveLs, cacheRepo, cloudFolderID, output) {
+  if (!requireNamespace("googledrive")) stop(requireNamespaceMsg("googledrive", "to use google drive files"))
   artifact <- isInRepo[[.cacheTableHashColName()]][1]
   browser(expr = exists("._cloudUpload_1"))
   artifactFileName <- CacheStoredFile(cacheRepo, hash = artifact)
@@ -100,7 +101,7 @@ cloudUpload <- function(isInRepo, outputHash, gdriveLs, cacheRepo, cloudFolderID
     newFileName <- paste0(outputHash,".rda")
   }
   isInCloud <- gsub(gdriveLs$name,
-                    pattern = paste0("\\.", file_ext(CacheStoredFile(cacheRepo, outputHash))),
+                    pattern = paste0("\\.", fileExt(CacheStoredFile(cacheRepo, outputHash))),
                     replacement = "") %in% outputHash
 
   if (!any(isInCloud)) {
@@ -109,7 +110,7 @@ cloudUpload <- function(isInRepo, outputHash, gdriveLs, cacheRepo, cloudFolderID
     numRetries <- 1
     while (numRetries < 6) {
       du <- try(retry(retries = numRetries,
-                      quote(drive_upload(media = artifactFileName, path = cloudFolderID,
+                      quote(googledrive::drive_upload(media = artifactFileName, path = cloudFolderID,
                                          name = newFileName, overwrite = FALSE))))
       if (is(du, "try-error")) {
         if (!isTRUE(any(grepl("overwrite", du)))) {
@@ -131,19 +132,19 @@ cloudUpload <- function(isInRepo, outputHash, gdriveLs, cacheRepo, cloudFolderID
 #'
 #' @param newFileName The character string of the local filename that the downloaded object will have
 #' @inheritParams cloudUpload
-#' @importFrom googledrive drive_download
 #' @inheritParams Cache
 cloudDownload <- function(outputHash, newFileName, gdriveLs, cacheRepo, cloudFolderID,
                           drv = getOption("reproducible.drv", RSQLite::SQLite()),
                           conn = getOption("reproducible.conn", NULL)) {
+  if (!requireNamespace("googledrive")) stop(requireNamespaceMsg("googledrive", "to use google drive files"))
   browser(expr = exists("._cloudDownload_1"))
   message("Downloading cloud copy of ", newFileName,", with cacheId: ", outputHash)
   localNewFilename <- file.path(tempdir2(), basename2(newFileName))
   isInCloud <- gsub(gdriveLs$name,
-                    pattern = paste0("\\.", file_ext(CacheStoredFile(cacheRepo, outputHash))),
+                    pattern = paste0("\\.", fileExt(CacheStoredFile(cacheRepo, outputHash))),
                     replacement = "") %in% outputHash
 
-  retry(quote(drive_download(file = as_id(gdriveLs$id[isInCloud][1]),
+  retry(quote(googledrive::drive_download(file = googledrive::as_id(gdriveLs$id[isInCloud][1]),
                              path = localNewFilename, # take first if there are duplicates
                              overwrite = TRUE)))
   if (useDBI()) {
@@ -168,10 +169,10 @@ cloudDownload <- function(outputHash, newFileName, gdriveLs, cacheRepo, cloudFol
 #'                      \code{outputToSave} are \code{Raster*} objects.
 #' @inheritParams cloudUpload
 #'
-#' @importFrom googledrive drive_download
 #' @keywords internal
 cloudUploadFromCache <- function(isInCloud, outputHash, cacheRepo, cloudFolderID,
                                  outputToSave, rasters) {
+  if (!requireNamespace("googledrive")) stop(requireNamespaceMsg("googledrive", "to use google drive files"))
   browser(expr = exists("._cloudUploadFromCache_1"))
   if (!any(isInCloud)) {
     cacheIdFileName <- CacheStoredFile(cacheRepo, outputHash)
@@ -181,8 +182,8 @@ cloudUploadFromCache <- function(isInCloud, outputHash, cacheRepo, cloudFolderID
     cloudFolderID <- checkAndMakeCloudFolderID(cloudFolderID = cloudFolderID, create = TRUE)
     message("Uploading new cached object ", newFileName,", with cacheId: ",
             outputHash," to cloud folder id: ", cloudFolderID$name, " or ", cloudFolderID$id)
-    du <- try(retry(quote(drive_upload(media = CacheStoredFile(cacheRepo, outputHash),
-                                       path = as_id(cloudFolderID), name = newFileName,
+    du <- try(retry(quote(googledrive::drive_upload(media = CacheStoredFile(cacheRepo, outputHash),
+                                       path = googledrive::as_id(cloudFolderID), name = newFileName,
                                        overwrite = FALSE))))
     if (is(du, "try-error")) {
       return(du)
@@ -192,17 +193,14 @@ cloudUploadFromCache <- function(isInCloud, outputHash, cacheRepo, cloudFolderID
 }
 
 cloudUploadRasterBackends <- function(obj, cloudFolderID) {
+  if (!requireNamespace("googledrive")) stop(requireNamespaceMsg("googledrive", "to use google drive files"))
   browser(expr = exists("._cloudUploadRasterBackends_1"))
   rasterFilename <- Filenames(obj)
   out <- NULL
   if (!is.null(unlist(rasterFilename)) && length(rasterFilename) > 0) {
     allRelevantFiles <- unique(rasterFilename)
-    # allRelevantFiles <- sapply(rasterFilename, function(file) {
-    #   unique(dir(dirname(file), pattern = paste(collapse = "|", file_path_sans_ext(basename(file))),
-    #              full.names = TRUE))
-    # })
     out <- lapply(allRelevantFiles, function(file) {
-      try(retry(quote(drive_upload(media = file,  path = cloudFolderID, name = basename(file),
+      try(retry(quote(googledrive::drive_upload(media = file,  path = cloudFolderID, name = basename(file),
                                overwrite = FALSE))))
     })
   }
@@ -212,23 +210,24 @@ cloudUploadRasterBackends <- function(obj, cloudFolderID) {
 cloudDownloadRasterBackend <- function(output, cacheRepo, cloudFolderID,
                                        drv = getOption("reproducible.drv", RSQLite::SQLite()),
                                        conn = getOption("reproducible.conn", NULL)) {
+  if (!requireNamespace("googledrive")) stop(requireNamespaceMsg("googledrive", "to use google drive files"))
   browser(expr = exists("._cloudDownloadRasterBackend_1"))
   rasterFilename <- Filenames(output)
   if (!is.null(unlist(rasterFilename)) && length(rasterFilename) > 0) {
     gdriveLs2 <- NULL
     cacheRepoRasterDir <- file.path(cacheRepo, "rasters")
     checkPath(cacheRepoRasterDir, create = TRUE)
-    simpleFilenames <- unique(file_path_sans_ext(basename2(unlist(rasterFilename))))
+    simpleFilenames <- unique(filePathSansExt(basename2(unlist(rasterFilename))))
     retry(quote({
-      gdriveLs2 <- drive_ls(path = as_id(cloudFolderID),
+      gdriveLs2 <- googledrive::drive_ls(path = as_id(cloudFolderID),
                             pattern = paste(collapse = "|", simpleFilenames))
     }))
 
-    if (all(simpleFilenames %in% file_path_sans_ext(gdriveLs2$name))) {
+    if (all(simpleFilenames %in% filePathSansExt(gdriveLs2$name))) {
       filenameMismatches <- unlist(lapply(seq_len(NROW(gdriveLs2)), function(idRowNum) {
         localNewFilename <- file.path(cacheRepoRasterDir, basename2(gdriveLs2$name[idRowNum]))
         filenameMismatch <- identical(localNewFilename, rasterFilename)
-        retry(quote(drive_download(file = gdriveLs2[idRowNum,],
+        retry(quote(googledrive::drive_download(file = gdriveLs2[idRowNum,],
                                    path = localNewFilename, # take first if there are duplicates
                                    overwrite = TRUE)))
         return(filenameMismatch)
@@ -243,13 +242,6 @@ cloudDownloadRasterBackend <- function(output, cacheRepo, cloudFolderID,
         } else {
           output@filename <- file.path(cacheRepoRasterDir, basename2(rasterFilename))
         }
-        # lapply(names(rasterFilename), function(rasName) {
-        #   output[[rasName]] <- .prepareFileBackedRaster(output[[rasName]],
-        #                                                 repoDir = cacheRepo, overwrite = FALSE,
-        #                                                 drv = drv, conn = conn)
-        # })
-        # output <- .prepareFileBackedRaster(output, repoDir = cacheRepo, overwrite = FALSE,
-        #                                    drv = drv, conn = conn)
       }
     } else {
       warning("Raster backed files are not available in googledrive; \n",
