@@ -1,27 +1,25 @@
-#' Make a temporary sub-directory or file in that subdirectory
+#' Move a file to a new location
 #'
-#' Create a temporary subdirectory in \code{.reproducibleTempPath()}, or a
-#' temporary file in that temporary subdirectory.
+#' @param from,to character vectors, containing file names or paths.
+#' @param overwrite logical indicating whether to overwrite destination file if it exists.
 #'
-#' @param sub Character string, length 1. Can be a result of
-#'   \code{file.path("smth", "smth2")} for nested temporary sub
-#'   directories.
-#' @param tempdir Optional character string where the temporary dir should be placed.
-#'   Defaults to \code{.reproducibleTempPath()}
+#' @return Logical indicating whether operation succeeded.
 #'
-#' @rdname tempFilesAndFolders
 #' @export
-tempdir2 <- function(sub = "", tempdir = getOption("reproducible.tempPath", .reproducibleTempPath())) {
-  checkPath(normPath(file.path(tempdir, sub)), create = TRUE)
+file.move <- function(from, to, overwrite = FALSE) {
+  stopifnot(file.exists(from))
+  res <- suppressWarnings(file.rename(from = from, to = to))
+  if (.isFALSE(res)) {
+    res2 <- file.copy(from = from, to = to, overwrite = overwrite)
+    if (isTRUE(res2)) {
+      file.remove(from)
+    }
+    return(res2)
+  } else {
+    return(res)
+  }
 }
 
-#' @param ... passed to \code{tempfile}, e.g., \code{fileext}
-#'
-#' @rdname tempFilesAndFolders
-#' @export
-tempfile2 <- function(sub = "", ...) {
-  normPath(file.path(tempdir2(sub = sub), basename(tempfile(...))))
-}
 
 #' Recursive copying of nested environments, and other "hard to copy" objects
 #'
@@ -85,7 +83,6 @@ tempfile2 <- function(sub = "", ...) {
 #'   # write deep copy code here
 #' })
 #' }
-
 setGeneric("Copy", function(object, filebackedDir, ...) {
   standardGeneric("Copy")
 })
@@ -130,7 +127,7 @@ setMethod(
 
     }
     return(object)
-  })
+})
 
 
 #' @rdname Copy
@@ -141,16 +138,14 @@ setMethod("Copy",
             message("Making a copy of the entire SQLite database: ",object@dbname,
                     "; this may not be desireable ...")
             RSQLite::sqliteCopyDatabase(object, con)
-          })
+})
 
 #' @rdname Copy
 setMethod("Copy",
           signature(object = "data.table"),
           definition = function(object, ...) {
             data.table::copy(object)
-          })
-
-
+})
 
 #' @rdname Copy
 setMethod("Copy",
@@ -163,8 +158,7 @@ setMethod("Copy",
             lapply(object, function(x) {
               Copy(x, ...)
             })
-          })
-
+})
 
 #' @rdname Copy
 setMethod("Copy",
@@ -176,14 +170,14 @@ setMethod("Copy",
               stop("There is no method to copy this refClass object; ",
                    "see developers of reproducible package")
             }
-          })
+})
 
 #' @rdname Copy
 setMethod("Copy",
           signature(object = "data.frame"),
           definition = function(object,  filebackedDir, ...) {
             object
-          })
+})
 
 #' @rdname Copy
 #' @inheritParams DBI::dbConnect
@@ -200,5 +194,4 @@ setMethod("Copy",
                 object <- .prepareFileBackedRaster(object, repoDir = filebackedDir, drv = drv, conn = conn)
             }
             object
-          })
-
+})
