@@ -72,7 +72,6 @@ checkGDALVersion <- function(version) {
 #' @inheritParams projectInputs.Raster
 #' @importFrom raster crop crs extract mask nlayers raster stack tmpDir
 #' @importFrom raster xmin xmax ymin ymax fromDisk setMinMax
-#' @importFrom sf st_as_sf st_write
 #' @importFrom sp SpatialPolygonsDataFrame spTransform
 #'
 #' @examples
@@ -109,13 +108,12 @@ checkGDALVersion <- function(version) {
 #' }
 #'
 fastMask <- function(x, y, cores = NULL, useGDAL = getOption("reproducible.useGDAL", TRUE), ...) {
-  if (!identical(crs(y), crs(x))) {
+  if (!identical(.crs(y), .crs(x))) {
     if (!is(y, "sf")) {
-      y <- spTransform(x = y, CRSobj = crs(x))
+      y <- spTransform(x = y, CRSobj = .crs(x))
     } else {
-      rn <- .requireNamespace("sf")
-      if (isFALSE(rn)) stop("Must install sf package")
-      y <- st_transform(x = y, crs = crs(x))
+      .requireNamespace("sf", stopOnFALSE = TRUE)
+      y <- sf::st_transform(x = y, crs = .crs(x))
     }
   }
 
@@ -160,7 +158,7 @@ fastMask <- function(x, y, cores = NULL, useGDAL = getOption("reproducible.useGD
       }
 
       ## GDAL requires file path to cutline - write to disk
-      tempSrcShape <- file.path(tempfile(tmpdir = raster::tmpDir()), ".shp", fsep = "")
+      tempSrcShape <- normPath(file.path(tempfile(tmpdir = raster::tmpDir()), ".shp", fsep = ""))
       ysf <- sf::st_as_sf(y)
       sf::st_write(ysf, tempSrcShape)
       tr <- res(x)
@@ -174,7 +172,7 @@ fastMask <- function(x, y, cores = NULL, useGDAL = getOption("reproducible.useGD
       # dType <- assessDataType(raster(tempSrcRaster), type = "GDAL")
       cores <- dealWithCores(cores)
       prll <- paste0("-wo NUM_THREADS=", cores, " ")
-      srcCRS <- as.character(raster::crs(raster::raster(tempSrcRaster)))
+      srcCRS <- as.character(.crs(raster::raster(tempSrcRaster)))
       targCRS <- srcCRS
       system(
         paste0(paste0(getOption("gdalUtils_gdalPath")[[1]]$path, "gdalwarp", exe, " "),
@@ -194,7 +192,7 @@ fastMask <- function(x, y, cores = NULL, useGDAL = getOption("reproducible.useGD
                "\"", tempDstRaster, "\""),
         wait = TRUE, intern = TRUE, ignore.stderr = TRUE)
       x <- raster(tempDstRaster)
-      x <- setMinMax(x)
+      x <- setMinMaxIfNeeded(x)
     } else {
       # Eliot removed this because fasterize::fasterize will handle cases where x[[1]] is too big
       #extentY <- extent(y)
@@ -238,7 +236,7 @@ fastMask <- function(x, y, cores = NULL, useGDAL = getOption("reproducible.useGD
 }
 
 #' @importFrom raster tmpDir
-bigRastersTmpFolder <- function() file.path(raster::tmpDir(), "bigRasters")
+bigRastersTmpFolder <- function() checkPath(Require::tempdir2(sub = "bigRasters"), create = TRUE)
 
 bigRastersTmpFile <- function() file.path(bigRastersTmpFolder(), "bigRasInput.tif")
 
@@ -294,10 +292,10 @@ findGDAL <- function() {
   }
 }
 
-attemptGDAL <- function(x, useGDAL) {
+attemptGDAL <- function(x, useGDAL = getOption("reproducible.useGDAL", TRUE)) {
   if (requireNamespace("gdalUtils", quietly = TRUE)) {
     browser(expr = exists("._attemptGDAL_1"))
-    crsIsNA <- is.na(crs(x))
+    crsIsNA <- is.na(.crs(x))
     cpim <- canProcessInMemory(x, 3)
     isTRUEuseGDAL <- isTRUE(useGDAL)
     forceGDAL <- identical(useGDAL, "force")
@@ -309,7 +307,7 @@ attemptGDAL <- function(x, useGDAL) {
         message("Can't use GDAL because crs is NA")
       if (cpim && isTRUEuseGDAL)
         message("useGDAL is TRUE, but problem is small enough for RAM; skipping GDAL; ",
-                "use GDAL = 'force' to override")
+                "useGDAL = 'force' to override")
 
       FALSE
     }
@@ -321,9 +319,43 @@ attemptGDAL <- function(x, useGDAL) {
 }
 
 maskWithRasterNAs <- function(x, y) {
+  origColors <- checkColors(x)
   if (canProcessInMemory(x, 3) && fromDisk(x))
     x[] <- x[]
+  x <- rebuildColors(x, origColors)
   m <- which(is.na(y[]))
   x[m] <- NA
   x
 }
+
+#' @importFrom raster maxValue minValue
+checkColors <- function(x) {
+  origColors <- .getColors(x)
+  origMaxValue <- maxValue(x)
+  origMinValue <- minValue(x)
+  list(origColors = origColors[[1]], origMinValue = origMinValue, origMaxValue = origMaxValue)
+}
+
+rebuildColors <- function(x, origColors) {
+  if (isTRUE(origColors$origMinValue != minValue(x) || origColors$origMaxValue != maxValue(x) ||
+      !identical(.getColors(x)[[1]], origColors$origColors))) {
+    if (length(origColors$origColors) == length(origColors$origMinValue:origColors$origMaxValue)) {
+      newSeq <- minValue(x):maxValue(x)
+      oldSeq <- origColors$origMinValue:origColors$origMaxValue
+      whFromOld <- match(newSeq, oldSeq)
+      x@legend@colortable <- origColors$origColors[whFromOld]
+    }
+  }
+  x
+}
+
+
+.getColors <- function(object) {
+  nams <- names(object)
+  cols <- lapply(nams, function(x) {
+    as.character(object[[x]]@legend@colortable)
+  })
+  names(cols) <- nams
+  return(cols)
+}
+
